pub fn gaussian_filter<A, D>(
data: &ArrayRef<A, D>,
sigma: A,
order: usize,
mode: BorderMode<A>,
truncate: usize,
) -> Array<A, D>Expand description
Gaussian filter for n-dimensional arrays.
Currently hardcoded with the PadMode::Reflect padding mode.
data- The input N-D data.sigma- Standard deviation for Gaussian kernel.order- The order of the filter along all axes. An order of 0 corresponds to a convolution with a Gaussian kernel. A positive order corresponds to a convolution with that derivative of a Gaussian.mode- Method that will be used to select the padded values. See theBorderModeenum for more information.truncate- Truncate the filter at this many standard deviations.
Panics if one of the axis’ lengths is lower than truncate * sigma + 0.5.