minimum_filter

Function minimum_filter 

pub fn minimum_filter<A, D>(
    data: &ArrayRef<A, D>,
    size: usize,
    mode: BorderMode<A>,
    origin: isize,
) -> Array<A, D>
Calculate a multidimensional minimum filter.

  • data - The input N-D data.
  • size - Length along which to calculate 1D minimum.
  • mode - Method that will be used to select the padded values. See the CorrelateMode enum for more information.
  • origin - Controls the placement of the filter on the input array’s pixels. A value of 0 centers the filter over the pixel, with positive values shifting the filter to the left, and negative ones to the right.