pad

Function pad 

pub fn pad<A, D>(
    data: &ArrayRef<A, D>,
    pad: &[[usize; 2]],
    mode: PadMode<A>,
) -> Array<A, D>
Pad an image.

  • data - A N-D array of the data to pad.
  • pad - Number of values padded to the edges of each axis.
  • mode - Method that will be used to select the padded values. See the PadMode enum for more information.