spline_filter

Function spline_filter 

pub fn spline_filter<A, D>(
    data: &ArrayRef<A, D>,
    order: usize,
    mode: BorderMode<A>,
) -> Array<f64, D>
where A: Copy + ToPrimitive, D: Dimension,
Multidimensional spline filter.

The multidimensional filter is implemented as a sequence of one-dimensional spline filters. The input data will be processed in f64 and returned as such.

  • data - The input N-D data.
  • order - The order of the spline.
  • mode - The mode parameter determines how the input array is extended beyond its boundaries.

Panics if order isn’t in the range [2, 5].