Function ndarray_ndimage::spline_filter1d[][src]

pub fn spline_filter1d<S, A, D>(
    data: &ArrayBase<S, D>,
    order: usize,
    axis: Axis
) -> Array<A, D> where
    S: Data<Elem = A>,
    A: 'static + Clone + Copy + Num + ToPrimitive,
    f64: AsPrimitive<A>,
    D: Dimension
Calculate a 1-D spline filter along the given axis.

The lines of the array along the given axis are filtered by a spline filter. The input data will be processed in f64 and converted back to the original datatype.

  • data - The input N-D data.
  • order - The order of the spline.
  • axis - The axis along which the spline filter is applied.

Panics if order isn’t in the range [0, 5].