uniform_filter

Function uniform_filter 

pub fn uniform_filter<A, D>(
    data: &ArrayRef<A, D>,
    size: usize,
    mode: BorderMode<A>,
) -> Array<A, D>
where A: Copy + Num + FromPrimitive + PartialOrd + 'static, D: Dimension,
Uniform filter for n-dimensional arrays.

Currently hardcoded with the PadMode::Reflect padding mode.

  • data - The input N-D data.
  • size - The len
  • mode - Method that will be used to select the padded values. See the BorderMode enum for more information.

Panics if size is zero, or one of the axis’ lengths is lower than size.