pub fn binary_opening(
mask: &ArrayRef3<bool>,
kernel: &ArrayRef3<bool>,
iterations: usize,
) -> MaskExpand description
Binary opening of a 3D binary image.
The opening of an input image by a structuring element is the dilation of the erosion of the image by the structuring element.
Unlike other libraries, the border values of the:
- dilation is always
false, to avoid dilating the borders - erosion is always
true, to avoid border effects
mask- Binary image to be opened.kernel- Structuring element used for the opening.iterations- The erosion step of the opening, then the dilation step are each repeated iterations times.