pub fn uniform_filter<A, D>(
data: &ArrayRef<A, D>,
size: usize,
mode: BorderMode<A>,
) -> Array<A, D>Expand description
Uniform filter for n-dimensional arrays.
Currently hardcoded with the PadMode::Reflect padding mode.
data- The input N-D data.size- The lenmode- Method that will be used to select the padded values. See theBorderModeenum for more information.
Panics if size is zero, or one of the axis’ lengths is lower than size.