pub fn uniform_filter1d<A, D>(
data: &ArrayRef<A, D>,
size: usize,
axis: Axis,
mode: BorderMode<A>,
) -> Array<A, D>Expand description
Uniform filter for 1-dimensional arrays.
data- The input N-D data.size- Length of the uniform filter.axis- The axis of input along which to calculate.mode- Method that will be used to select the padded values. See theBorderModeenum for more information.
Panics if size is zero, or the axis length is lower than size.